=======
Credits
=======

Development Lead
----------------
* GoTLiuM InSPiRiT (`gotlium <https://github.com/gotlium>`_)

Contributors
------------

* Egor (`orlovegor <https://github.com/orlovegor>`_)
* DikNuken (`DikNuken <https://github.com/DikNuken>`_)
* BenjaminRigaud (`BenjaminRigaud <https://github.com/benjaminrigaud>`_)